\name{rvbm}
\alias{rvbm}
\alias{rvbm.default}
\alias{print.rvbm}

\title{GPU Accelerated Variational Bayesian Multiclass Probit Regression}

\description{
  The \code{rvbm} method trains a Bayesian classification model 
  with Gaussian process priors. It is based on the variational sparse
  approximation technique used by Girolami and Rogers, as well as the
  \code{vbmp} package implemented by Lama and Girolami.
  
  In the non-free \code{rpudplus} add-on, the \code{rvbm} method
  is implemented in NVIDIA CUDA, and assumes necessary
  double precision CUDA hardware support. 
    
  While there is no GPU-acceleration in the free \code{rpud} package,
  it includes optimized R code nonetheless. 
}
\usage{
\method{rvbm}{default}(X, t.class, X.TEST, t.class.TEST, 
        theta = rep(1, ncol(X)), control = list())
}
\arguments{
  \item{X}{Feature matrix for the model to fit.}
  \item{t.class}{Response vector for the feature matrix.}
  \item{X.TEST}{Out-of-sample test matrix for prediction.}
  \item{t.class.TEST}{Out-of-sample response values.}
  \item{theta}{Covariance parameters for each feature dimension.}
  \item{control}{A list of control parameters including the following:
    \itemize{
      \item{InfoLevel: }{Trace level }
      \item{sFILE.TRACE: }{Path of trace file }
      \item{bThetaEstimate: }{Enable covariance parameter estimate }
      \item{sKernelType: }{Gaussian process kernel, default is \code{gaussian}:
        \itemize{
            \item{linear:     }{\eqn{u'v}{u'*v}}
            \item{polynomial: }{\eqn{(u'v + c)^{d}}{(u'*v + coef0)^degree}}
            \item{cauchy:     }{\eqn{(1+|u-v|^2)^{-d}}{(1+|u-v|^2)^(-degree)}}
            \item{gaussian:   }{\eqn{exp(-|u-v|^2)}{exp(-|u-v|^2)}} 
            \item{laplacian:  }{\eqn{exp(-|u-v|)}{exp(-|u-v|)}}
            \item{sigmoid:    }{\eqn{tanh(u'v + c)}{tanh(u'*v + coef0)}}
        }
      }
      \item{kDegree: }{\code{coef0} parameter for \code{polynomial} and \code{cauchy} kernels }
      \item{kCoef0: }{\code{degree} parameter for \code{polynomial} and \code{sigmoid} kernels, usually 0 or 1 }
      \item{maxIts: }{Maximum number of EM steps allowed (default 50).}
      \item{Thresh: }{Convergence threshold on marginal likelihood lowerbound (default 1e-4).}
      \item{method: }{Numerical integration method:
        \itemize{
          \item{quadrature: }{Gaussian quadrature (default)}
          \item{classic: }{Naive Monte Carlo}
          }
        }
      \item{nNodesQuad: }{Number of quadrature nodes (default 49).}     
      \item{nSampsTG: }{Number of number of truncated Gaussian samples (default 1000).}
      \item{nSampsIS: }{Importance sampler population (default 1000).} 
      \item{nSmallNo: }{Numerical underflow tolerance (default 1e-10).} 
      \item{parGammaTau: }{Location of Gamma prior over covariance parameters (default 1e-6).}
      \item{parGammaSigma: }{Scale of Gamma prior over covariance parameters (default 1e-6).}
      \item{bMonitor: }{TRUE to collect monitor convergence diagnostics (default FALSE).}
      \item{bPlotFitting: }{TRUE to plot test performance results at each iteration (default FALSE).}
      \item{bInitM: }{Optionally initializes latent Gaussian process random variables.
        Set as TRUE to exactly match results from \code{vbmp} (default FALSE).}
    }
  }
}
\value{
An S3 object of class "rvbm" with the following components: 
  \item{Kc}{Number of response categories}
  \item{Ptest}{Matrix of predicted posterior probability }
  \item{X}{Feature matrix of the Gaussian process model}
  \item{cholPHI}{Upper triangular Cholesky factor of the symmetric kernel matrix}
  \item{Y}{Matrix of auxiliary variables}
  \item{M}{Matrix of latent Gaussian process random variables}            
  \item{THETA}{covariance kernel hyperparameters}            
  \item{sKernelType}{Kernel type of the Gaussian process model}            
  \item{testErr}{Percentage of posterior prediction error.}
  \item{PL}{Predictive log likelihood during each model fitting iteration.}
  \item{lowerBound}{Lower bound estimates of marginal likelihood during each model fitting iteration.}            
}
\details{
 Sharing a single covariance function across all classes.
}
\references{
  \itemize{
    \item
      Girolami M, Rogers S, \emph{Variational Bayesian Multinomial Probit 
      Regression with Gaussian Process Priors}, Neural Computation 18, 1790-1817 (2006).\cr

     \item
      Lama N, Girolami M \emph{vbmp: Variational Bayesian Multinomial Probit 
      Regression for multi-class classification in R}, Bioinformatics 24(1):135-136 (2008).\cr 
      \url{http://bioinformatics.oxfordjournals.org/cgi/content/short/btm535v1}
  }
}
\author{
  Chi Yau (based on the \code{vbmp} R doc by Lama and Girolami)\cr
  \email{chi.yau@r-tutor.com}
}
\seealso{
  \code{\link{predict.rvbm}}
  \code{\link{plot.rvbm}}
  \code{\link{rpusvm}}
  \code{vbmp}
}
\examples{
\dontrun{
library(rpud)

x <- rvbm.sample.train$X
y <- rvbm.sample.train$t.class
model.rvbm <- rvbm( 
    x, y, x, y,
    theta = rep(1, ncol(x)), 
    control = list(
            sKernelType="gaussian", 
            bThetaEstimate=TRUE, 
            bMonitor=TRUE,
            maxIts=12,
            InfoLevel=1) 
)

summary(model.rvbm)

}}
\keyword{neural}
\keyword{nonlinear}
\keyword{classif}

